@@ -1,6 +1,6 @@
 # test logging functions
 
-import dectools
+import dectools.dectools as dectools
 
 from print_buffer import print_buffer
 p = print_buffer()
